@@ -12,20 +12,23 @@
 #include <cstdint>
 #include <cstdio>
 #include <cstring>
+#include <istream>
 #include <memory>
 #include <stdexcept>
 #include <string>
+#include <string_view>
 #include <utility>
 #include <vector>
 #include <fcitx-config/iniparser.h>
 #include <fcitx-utils/capabilityflags.h>
+#include <fcitx-utils/fdstreambuf.h>
 #include <fcitx-utils/i18n.h>
 #include <fcitx-utils/key.h>
 #include <fcitx-utils/keysym.h>
 #include <fcitx-utils/log.h>
 #include <fcitx-utils/macros.h>
 #include <fcitx-utils/misc.h>
-#include <fcitx-utils/standardpath.h>
+#include <fcitx-utils/standardpaths.h>
 #include <fcitx-utils/stringutils.h>
 #include <fcitx-utils/textformatflags.h>
 #include <fcitx-utils/utf8.h>
@@ -463,20 +466,19 @@ enum class FcitxSkkDictType { FSDT_Invalid, FSDT_File, FSTD_Server };
 
 void SkkEngine::loadDictionary() {
     dictionaries_.clear();
-    auto file = StandardPath::global().open(StandardPath::Type::PkgData,
-                                            "skk/dictionary_list", O_RDONLY);
+    auto file = StandardPaths::global().open(StandardPathsType::PkgData,
+                                             "skk/dictionary_list");
 
-    UniqueFilePtr fp(fdopen(file.fd(), "rb"));
-    if (!fp) {
+    if (!file.isValid()) {
         return;
     }
-    file.release();
 
-    UniqueCPtr<char> buf;
-    size_t len = 0;
+    IFDStreamBuf buf(file.fd());
+    std::istream in(&buf);
+    std::string line;
 
-    while (getline(buf, &len, fp.get()) != -1) {
-        const auto trimmed = stringutils::trim(buf.get());
+    while (std::getline(in, line)) {
+        const auto trimmed = stringutils::trimView(line);
         const auto tokens = stringutils::split(trimmed, ",");
 
         if (tokens.size() < 3) {
@@ -533,6 +535,12 @@ void SkkEngine::loadDictionary() {
                 continue;
             }
             if (mode == 1) {
+                std::string_view partialpath = path;
+                if (stringutils::consumePrefix(partialpath,
+                                               "$XDG_DATA_DIRS/")) {
+                    path = StandardPaths::global().locate(
+                        StandardPathsType::Data, partialpath);
+                }
                 if (stringutils::endsWith(path, ".cdb")) {
                     SkkCdbDict *dict =
                         skk_cdb_dict_new(path.data(), encoding.data(), nullptr);
@@ -549,19 +557,17 @@ void SkkEngine::loadDictionary() {
                     }
                 }
             } else {
-                constexpr char configDir[] = "$FCITX_CONFIG_DIR/";
-                constexpr auto len = sizeof(configDir) - 1;
-                std::string realpath = path;
-                if (stringutils::startsWith(path, configDir)) {
-                    realpath = stringutils::joinPath(
-                        StandardPath::global().userDirectory(
-                            StandardPath::Type::PkgData),
-                        path.substr(len));
+                std::string_view partialpath = path;
+                if (stringutils::consumePrefix(partialpath,
+                                               "$FCITX_CONFIG_DIR/")) {
+                    path = StandardPaths::global().userDirectory(
+                               StandardPathsType::PkgData) /
+                           partialpath;
                 }
-                SkkUserDict *userdict = skk_user_dict_new(
-                    realpath.data(), encoding.data(), nullptr);
+                SkkUserDict *userdict =
+                    skk_user_dict_new(path.data(), encoding.data(), nullptr);
                 if (userdict) {
-                    SKK_DEBUG() << "Adding user dict: " << realpath;
+                    SKK_DEBUG() << "Adding user dict: " << path;
                     dictionaries_.emplace_back(SKK_DICT(userdict));
                 }
             }
@@ -748,6 +754,7 @@ void SkkState::updateUI() {
         inputPanel.reset();
         ic_->updatePreedit();
         engine_->instance()->showInputMethodInformation(ic_);
+        ic_->updateUserInterface(UserInterfaceComponent::InputPanel);
         return;
     }
 
